# Tikos Reasoning Platform

Tikos Reasoning Platform harnesses the power of empirically established 2nd-generation AI and statistical toolsets to offer its users advanced 3rd-generation AI capabilities.

## How to access the platform

To get Alpha API keys, please register your request via https://tikos.tech/

## Licence

Apache-2.0